@@ -6,16 +6,17 @@ Tools for analyzing UEFI firmware and checking UEFI modules with FwHunt rules
 
 __author__ = "FwHunt team"
 __email__ = "fwhunt@binarly.io"
-__version__ = "2.0.0"
+__version__ = "2.1.1"
 
 from .uefi_analyzer import UefiAnalyzer, UefiAnalyzerError
-from .uefi_scanner import UefiRule, UefiScanner
+from .uefi_scanner import UefiRule, UefiScanner, UefiScannerError
 from .uefi_te import TerseExecutableParser
 
 __all__ = [
     "UefiAnalyzer",
     "UefiRule",
     "UefiScanner",
+    "UefiScannerError",
     "TerseExecutableParser",
     "UefiAnalyzerError",
 ]
